@@ -114,7 +114,7 @@ class PipfileLoader(plette.pipfiles.Pipfile):
             source["name"] = get_url_name(source["url"])
         if "verify_ssl" not in source:
             source["verify_ssl"] = "https://" in source["url"]
-        if not isinstance(source["verify_ssl"], bool):
+        if isinstance(source["verify_ssl"], str):
             source["verify_ssl"] = source["verify_ssl"].lower() == "true"
         return source
 
