@@ -28,6 +28,8 @@ from vistir.contextmanagers import cd, temp_path
 from vistir.misc import run
 from vistir.path import create_tracked_tempdir, ensure_mkdir_p, mkdir_p, rmtree
 
+from ..environment import MYPY_RUNNING
+from ..exceptions import RequirementError
 from .utils import (
     get_default_pyproject_backend,
     get_name_variants,
@@ -37,8 +39,6 @@ from .utils import (
     split_vcs_method_from_uri,
     strip_extras_markers_from_requirement,
 )
-from ..environment import MYPY_RUNNING
-from ..exceptions import RequirementError
 
 try:
     from setuptools.dist import distutils, Distribution
@@ -195,7 +195,7 @@ def make_base_requirements(reqs):
             requirements.add(req)
         elif isinstance(req, pkg_resources_requirements.Requirement):
             requirements.add(BaseRequirement.from_req(req))
-        elif req and not req.startswith("#"):
+        elif req and isinstance(req, six.string_types) and not req.startswith("#"):
             requirements.add(BaseRequirement.from_string(req))
     return requirements
 
@@ -240,10 +240,15 @@ def get_package_dir_from_setupcfg(parser, base_dir=None):
         if "package_dir" in setup_py:
             package_lookup = setup_py["package_dir"]
             if not isinstance(package_lookup, Mapping):
-                return package_lookup
-            return package_lookup.get(
+                package_dir = package_lookup
+            package_dir = package_lookup.get(
                 next(iter(list(package_lookup.keys()))), package_dir
             )
+    if not os.path.isabs(package_dir):
+        if not base_dir:
+            package_dir = os.path.join(os.path.getcwd(), package_dir)
+        else:
+            package_dir = os.path.join(base_dir, package_dir)
     return package_dir
 
 
@@ -296,7 +301,8 @@ def parse_setup_cfg(setup_cfg_path):
     parser = configparser.ConfigParser(default_opts)
     parser.read(setup_cfg_path)
     results = {}
-    package_dir = get_package_dir_from_setupcfg(parser, base_dir=os.getcwd())
+    base_dir = os.path.dirname(os.path.abspath(setup_cfg_path))
+    package_dir = get_package_dir_from_setupcfg(parser, base_dir=base_dir)
     name, version = get_name_and_version_from_setupcfg(parser, package_dir)
     results["name"] = name
     results["version"] = version
@@ -638,6 +644,8 @@ class Analyzer(ast.NodeVisitor):
         self.functions = []
         self.strings = []
         self.assignments = {}
+        self.binOps = []
+        self.binOps_map = {}
         super(Analyzer, self).__init__()
 
     def generic_visit(self, node):
@@ -652,6 +660,17 @@ class Analyzer(ast.NodeVisitor):
             self.assignments.update(ast_unparse(node, initial_mapping=True))
         super(Analyzer, self).generic_visit(node)
 
+    def visit_BinOp(self, node):
+        left = ast_unparse(node.left, initial_mapping=True)
+        right = ast_unparse(node.right, initial_mapping=True)
+        node.left = left
+        node.right = right
+        self.binOps.append(node)
+
+    def unmap_binops(self):
+        for binop in self.binOps:
+            self.binOps_map[binop] = ast_unparse(binop, analyzer=self)
+
     def match_assignment_str(self, match):
         return next(
             iter(k for k in self.assignments if getattr(k, "id", "") == match), None
@@ -678,6 +697,26 @@ def ast_unparse(item, initial_mapping=False, analyzer=None, recurse=True):  # no
         unparsed = item.s
     elif isinstance(item, ast.Subscript):
         unparsed = unparse(item.value)
+    elif isinstance(item, ast.BinOp):
+        if analyzer and item in analyzer.binOps_map:
+            unparsed = analyzer.binOps_map[item]
+        elif isinstance(item.op, ast.Add):
+            if not initial_mapping:
+                right_item = unparse(item.right)
+                left_item = unparse(item.left)
+                if not all(
+                    isinstance(side, (six.string_types, int, float, list, tuple))
+                    for side in (left_item, right_item)
+                ):
+                    item.left = left_item
+                    item.right = right_item
+                    unparsed = item
+                else:
+                    unparsed = right_item + left_item
+            else:
+                unparsed = item
+        elif isinstance(item.op, ast.Sub):
+            unparsed = unparse(item.left) - unparse(item.right)
     elif isinstance(item, ast.Name):
         if not initial_mapping:
             unparsed = item.id
@@ -787,6 +826,7 @@ def ast_parse_setup_py(path):
     # type: (S) -> Dict[Any, Any]
     ast_analyzer = ast_parse_file(path)
     setup = {}  # type: Dict[Any, Any]
+    ast_analyzer.unmap_binops()
     for k, v in ast_analyzer.function_map.items():
         fn_name = ""
         if isinstance(k, ast.Name):
